#!/usr/bin/perl
use warnings;
use strict;

# This script parses the JavaScript source file containing the full list of
# publisher ranges, found here:
#     http://www.isbn-international.org/converter/ranges.js
# which is used to generate the table shown here:
#     http://www.isbn-international.org/converter/ranges.htm
#
# Download the JavaScript and supply it as the standard input to this program,
# then do 'make isbn/data.lua'.

my $js = do { local $/; <> };

# Remove JS comments.
$js =~ s!/\*.*?\*/!!gs;
$js =~ s!//.*!!g;

my %prefix_range = $js =~ /^gi\.area(\d+)\.pubrange\s*=\s*"([^\s"]+)";?\s*$/gm;
die unless keys %prefix_range;

open my $out_ranges, '>', 'prefix-ranges.txt' or die $!;
for my $prefix (sort keys %prefix_range) {
    for my $range (split ';', $prefix_range{$prefix}) {
        $range =~ /^(\d+)(?:-(\d+))?$/
            or die "prefix $prefix: bad range '$range'";
        my ($start, $end) = ($1, $2);
        $end = $start unless defined $end;
        print $out_ranges join(' ', $prefix, $start, $end), "\n";
    }
}

my %prefix_name = $js =~ /^gi\.area(\d+)\.text\s*=\s*"([^"]+)";?\s*$/gm;
die unless keys %prefix_range;

open my $out_names, '>', 'prefix-names.txt' or die $!;
for my $prefix (sort keys %prefix_name) {
    my $name = $prefix_name{$prefix};
    for ($name) {
        s/ - no ranges fixed yet$//;
        s/^(Philippines)\?$/$1/;
        s/^Egypr$/Egypt/;
    }
    print $out_names "$prefix $name\n";
}

# vi:ts=4 sw=4 expandtab
