local ISBN = require "isbn"
require "isbn-test"
local testcase = TestCase("Test an Albanian ISBN")

local function test_isbn (input, expected)
    local isbn, err = ISBN:new(input)
    assert_table(isbn)
    assert_nil(err)
    assert_isa(isbn, ISBN)
    is(input, isbn:isbn(), "isbn() method")
    is(expected.group_code, isbn:group_code(), "has right group code")
    is(expected.publisher, isbn:publisher_code(), "has right publisher")
    is(expected.group_name, isbn:group_name(), "has right group name")
    is(expected.article_code, isbn:article_code(), "has right article code" )
    is(expected.checksum, isbn:checksum(), "has right checksum" )
    is(expected.with_hyphens, tostring(isbn), "stringify metamethod")
end

function testcase:test_loaded ()
    assert_function(ISBN.new)
end

function testcase:test_albanian ()
    test_isbn("9992701579", {
        with_hyphens = "99927-0-157-9",
        group_name   = "Albania",
        group_code   = "99927",
        publisher    = "0",
        article_code = "157",
        checksum     = "9",
    })
end

function testcase:test_eq_isbn10 ()
    local isbn10 = ISBN:new("9992701579")
    assert_true(isbn10:eq("999-270 1 5 7-9"))
    assert_true(isbn10:eq(ISBN:new("9992701579")))
    assert_true(isbn10:eq("978-99927-0-157-7"))
    assert_true(isbn10:eq(ISBN:new("978-99927-0-157-7")))

    assert_false(isbn10:eq("000761263X"))
    assert_false(isbn10:eq(ISBN:new("000761263X")))
    assert_false(isbn10:eq("9780900083181"))
    assert_false(isbn10:eq(ISBN:new("9780900083181")))

    assert_error(function () isbn10:eq("invalid") end)
end

function testcase:test_eq_isbn13 ()
    local isbn13 = ISBN:new("978-99927-0-157-7")
    assert_true(isbn13:eq("999-270 1 5 7-9"))
    assert_true(isbn13:eq(ISBN:new("9992701579")))
    assert_true(isbn13:eq("978-99927-0-157-7"))
    assert_true(isbn13:eq(ISBN:new("978-99927-0-157-7")))

    assert_false(isbn13:eq("000761263X"))
    assert_false(isbn13:eq(ISBN:new("000761263X")))
    assert_false(isbn13:eq("9780900083181"))
    assert_false(isbn13:eq(ISBN:new("9780900083181")))
end

function testcase:test_eq_operator ()
    assert_true(ISBN:new("9992701579")     == ISBN:new("9992701579"))
    assert_true(ISBN:new("9789992701577")  == ISBN:new("9992701579"))
    assert_true(ISBN:new("9992701579")     == ISBN:new("9789992701577"))
    assert_true(ISBN:new("9789992701577")  == ISBN:new("9789992701577"))

    assert_false(ISBN:new("9992701579")    == ISBN:new("000761263X"))
    assert_false(ISBN:new("9789992701577") == ISBN:new("000761263X"))
    assert_false(ISBN:new("9992701579")    == ISBN:new("9780900083181"))
    assert_false(ISBN:new("9789992701577") == ISBN:new("9780900083181"))

    assert_true(ISBN:new("9992701579")    ~= ISBN:new("000761263X"))
    assert_true(ISBN:new("9789992701577") ~= ISBN:new("000761263X"))
    assert_true(ISBN:new("9992701579")    ~= ISBN:new("9780900083181"))
    assert_true(ISBN:new("9789992701577") ~= ISBN:new("9780900083181"))
end

lunit.run()
-- vi:ts=4 sw=4 expandtab
